@@ -14,27 +14,8 @@ import re
 
 
 def parenthesize_return(content: str) -> str:
-    ptn_no_value = r"return\s*;"
-    ptn_surrounded = r"return\s+?(?P<value>\(.*\))\s*;"
-    ptn_paren_leaded = r"return\s+\(?(?P<value>(?=\().*)\)?\s*;"
-    ptn_other = r"return\s+(?P<value>.*)\s*;"
-
-    if re.search(ptn_no_value, content):
-        return content
-
-    if re.search(ptn_surrounded, content):
-        return content
-
-    if re.search(ptn_paren_leaded, content):
-        return re.sub(
-            ptn_paren_leaded,
-            lambda match: "return ({});".format(match.group("value").strip()),
-            content,
-            re.DOTALL,
-        )
-
     return re.sub(
-        ptn_other,
+        r"return\s+(?!;)(?!\(.*\);)(?P<value>\(?.*?)\s*;",
         lambda match: "return ({});".format(match.group("value").strip()),
         content,
         re.DOTALL,
@@ -59,7 +40,7 @@ def remove_multiline_condition_space(content: str) -> str:
 
 def insert_void(content: str) -> str:
     return re.sub(
-        r"(?P<funcdef>[0-9a-zA-Z_]*\t+[0-9a-zA-Z_]*\s*)\(\s*\)",
+        r"(?P<funcdef>[0-9a-zA-Z_]+\t+[0-9a-zA-Z_]*\s*)\(\s*\)",
         lambda match: "{}({})".format(match.group("funcdef"), "void"),
         content,
     )
